@@ -72,6 +72,7 @@ typedef struct
 	guint size_changed_handler;
 	guint notify_xpad_handler;
 	guint notify_ypad_handler;
+	guint notify_visible_handler;
 } Renderer;
 
 enum
@@ -83,6 +84,7 @@ enum
 	LEAVE_NOTIFY_EVENT,
 	QUERY_TOOLTIP_EVENT,
 	REALIZE,
+	STYLE_UPDATED,
 	LAST_EXTERNAL_SIGNAL
 };
 
@@ -132,6 +134,9 @@ static gboolean on_view_query_tooltip (GtkSourceView   *view,
                                        GtkTooltip      *tooltip,
                                        GtkSourceGutter *gutter);
 
+static void on_view_style_updated (GtkSourceView    *view,
+                                   GtkSourceGutter  *gutter);
+
 static void do_redraw (GtkSourceGutter *gutter);
 static void update_gutter_size (GtkSourceGutter *gutter);
 
@@ -158,6 +163,14 @@ on_renderer_notify_padding (GtkSourceGutterRenderer *renderer,
 	update_gutter_size (gutter);
 }
 
+static void
+on_renderer_notify_visible (GtkSourceGutterRenderer *renderer,
+                            GParamSpec              *spec,
+                            GtkSourceGutter         *gutter)
+{
+	update_gutter_size (gutter);
+}
+
 static Renderer *
 renderer_new (GtkSourceGutter         *gutter,
               GtkSourceGutterRenderer *renderer,
@@ -197,6 +210,12 @@ renderer_new (GtkSourceGutter         *gutter,
 		                  G_CALLBACK (on_renderer_notify_padding),
 		                  gutter);
 
+	ret->notify_visible_handler =
+		g_signal_connect (ret->renderer,
+		                  "notify::visible",
+		                  G_CALLBACK (on_renderer_notify_visible),
+		                  gutter);
+
 	return ret;
 }
 
@@ -215,6 +234,9 @@ renderer_free (Renderer *renderer)
 	g_signal_handler_disconnect (renderer->renderer,
 	                             renderer->notify_ypad_handler);
 
+	g_signal_handler_disconnect (renderer->renderer,
+	                             renderer->notify_visible_handler);
+
 	_gtk_source_gutter_renderer_set_view (renderer->renderer,
 	                                      NULL,
 	                                      GTK_TEXT_WINDOW_PRIVATE);
@@ -334,6 +356,12 @@ set_view (GtkSourceGutter *gutter,
 		                  "realize",
 		                  G_CALLBACK (on_view_realize),
 		                  gutter);
+
+	gutter->priv->signals[STYLE_UPDATED] =
+		g_signal_connect (view,
+		                  "style-updated",
+		                  G_CALLBACK (on_view_style_updated),
+		                  gutter);
 }
 
 static void
@@ -493,6 +521,8 @@ gtk_source_gutter_constructed (GObject *object)
 	{
 		gutter->priv->orientation = GTK_ORIENTATION_VERTICAL;
 	}
+
+	G_OBJECT_CLASS (gtk_source_gutter_parent_class)->constructed (object);
 }
 
 static void
@@ -913,6 +943,8 @@ on_view_draw (GtkSourceView   *view,
 	GtkTextIter selection_end;
 	gboolean has_selection;
 	gint idx;
+	GtkStyleContext *style_context;
+	GdkRGBA fg_color;
 
 	window = gtk_source_gutter_get_window (gutter);
 
@@ -990,6 +1022,14 @@ on_view_draw (GtkSourceView   *view,
 	item = gutter->priv->renderers;
 	idx = 0;
 
+	style_context = gtk_widget_get_style_context (GTK_WIDGET (view));
+
+	gtk_style_context_get_color (style_context,
+	                             gtk_widget_get_state (GTK_WIDGET (view)),
+	                             &fg_color);
+
+	gdk_cairo_set_source_rgba (cr, &fg_color);
+
 	while (item)
 	{
 		Renderer *renderer = item->data;
@@ -1534,6 +1574,13 @@ on_view_query_tooltip (GtkSourceView   *view,
 	                                                 tooltip);
 }
 
+static void
+on_view_style_updated (GtkSourceView   *view,
+                       GtkSourceGutter *gutter)
+{
+	gtk_source_gutter_queue_draw (gutter);
+}
+
 void
 gtk_source_gutter_set_padding (GtkSourceGutter *gutter,
                                gint             xpad,
