@@ -624,38 +624,25 @@ get_css_color_style (GtkSourceStyle *style,
                      gchar         **text)
 {
 	GdkRGBA color;
-	gchar *bg_color, *text_color;
 
 	if (get_color (style, FALSE, &color))
 	{
+		gchar *bg_color;
 		bg_color = gdk_rgba_to_string (&color);
-	}
-	else
-	{
-		bg_color = NULL;
-	}
-
-	if (get_color (style, TRUE, &color))
-	{
-		text_color = gdk_rgba_to_string (&color);
-	}
-	else
-	{
-		text_color = NULL;
-	}
-
-	if (bg_color)
-	{
 		*bg = g_strdup_printf ("%s: %s;\n", "background-color", bg_color);
+		g_free (bg_color);
 	}
 	else
 	{
 		*bg = NULL;
 	}
 
-	if (text_color)
+	if (get_color (style, TRUE, &color))
 	{
+		gchar *text_color;
+		text_color = gdk_rgba_to_string (&color);
 		*text = g_strdup_printf ("%s: %s;\n", "color", text_color);
+		g_free (text_color);
 	}
 	else
 	{
@@ -682,6 +669,9 @@ append_css_style (GString        *string,
 		g_string_append_printf (string, css_style, state,
 		                        bg != NULL ? bg : "",
 		                        text != NULL ? text : "");
+
+		g_free (bg);
+		g_free (text);
 	}
 }
 
@@ -795,6 +785,12 @@ update_cursor_colors (GtkWidget      *widget,
 
 		context = gtk_widget_get_style_context (widget);
 		gtk_style_context_get_background_color (context, 0, &secondary_color);
+
+		/* shade the secondary cursor */
+		secondary_color.red *= 0.5;
+		secondary_color.green *= 0.5;
+		secondary_color.blue *= 0.5;
+
 		secondary = &secondary_color;
 	}
 
